Cheetah.Tests.Filters module — Cheetah3 - The Python-Powered Template Engine

# Cheetah.Tests.Filters module

class `Cheetah.Tests.Filters.` `BasicCodeHighlighterFilterTest`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Test that our code highlighter filter works

  `test_Html`()
  `test_Python`()

class `Cheetah.Tests.Filters.` `BasicMarkdownFilterTest`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Test that our markdown filter works

  `test_BasicHeader`()